@@ -1,5 +1,5 @@
-__version__ = "0.1.1"
-__description__ = "Calibrate the internal and external parameters of cameras, rectify stereo cameras by opencv."
+__version__ = "0.2.2"
+__description__ = "Calibrate the internal and external parameters of cameras, rectify stereo cameras by OpenCV python."
 __license__ = "MIT"
 __author__ = "DIYer22"
 __author_email__ = "ylxx@live.com"
